@@ -1,6 +1,6 @@
 package Weightbot::API;
 {
-  $Weightbot::API::VERSION = '0.04';
+  $Weightbot::API::VERSION = '1.0.0';
 }
 
 # ABSTRACT: get Weightbot iPhone app data from weightbot.com
@@ -12,6 +12,7 @@ use Carp;
 use WWW::Mechanize;
 use Class::Date qw(date);
 use File::Slurp;
+use IO::Socket::SSL qw();
 
 
 sub new {
@@ -108,7 +109,11 @@ sub _get_data_if_needed {
 
     unless ($self->{raw_data}) {
         my $mech = WWW::Mechanize->new(
-            agent => "Weightbot::API/$Weightbot::API::VERSION"
+            agent => "Weightbot::API/$Weightbot::API::VERSION",
+            ssl_opts => {
+                SSL_verify_mode => IO::Socket::SSL::SSL_VERIFY_NONE,
+                verify_hostname => 0,
+            },
         );
 
         $mech->get( $self->{site} . '/account/login');
@@ -150,7 +155,7 @@ Weightbot::API - get Weightbot iPhone app data from weightbot.com
 
 =head1 VERSION
 
-version 0.04
+version 1.0.0
 
 =head1 SYNOPSIS
 
@@ -182,6 +187,9 @@ browser.
 
 =head2 NOTES
 
+Weightbot::API version numbers uses Semantic Versioning standart.
+Please visit L<http://semver.org/> to find out all about this great thing.
+
 While debugging your programme that uses this module it is not a great idea to
 send requests to weightbot.com on every test run. This module can cache data
 to file. The module will read data from the cache file if the file exists or
